"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const MemcachedPlus = require("@vingle/memcache-plus"); // tslint:disable-line
class MemcachedDriver {
    constructor(serverURL, options) {
        this.serverURL = serverURL;
        this.options = options;
        this.client = new MemcachedPlus({
            hosts: [serverURL],
            autodiscover: options.autoDiscovery || false,
            netTimeout: 500,
            reconnect: true,
        });
    }
    async get(key) {
        const res = await this.client.get(key);
        if (res === null) {
            return undefined;
        }
        else {
            return res;
        }
    }
    async getMulti(keys) {
        const values = await this.client.getMulti(keys);
        const res = {};
        for (const key in values) {
            if (values.hasOwnProperty(key)) {
                res[key] = values[key];
            }
        }
        return res;
    }
    async set(key, value, lifetime) {
        await this.client.set(key, value, lifetime);
    }
    async del(key) {
        return await this.client.delete(key);
    }
    async flush() {
        await this.client.flush();
    }
}
exports.MemcachedDriver = MemcachedDriver;
//# sourceMappingURL=memcached.js.map